| coef | R Documentation |
Gets coefficients for all the terms in an MCMC object.
## S3 method for class 'mcmc'
coef(
object,
conf_level = 0.95,
estimate = median,
simplify = TRUE,
directional_information = FALSE,
...
)
object |
The MCMC object to get the coefficients for |
conf_level |
A number specifying the confidence level. By default 0.95. |
estimate |
The function to use to calculate the estimate. |
simplify |
|
directional_information |
A flag specifying whether the svalue column
should be calculated using |
... |
Unused. |
An data frame of the coefficients with the columns indicating the
term, estimate,
lower and upper credible intervals and svalue
coef(mcmc): Get coefficients for terms in mcmc object
stats::coef
coef(mcmcr_example, directional_information = FALSE)
coef(mcmcr_example, directional_information = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.