Learn R Programming

mcmcr (version 0.7.0)

coef: Term coefficients

Description

Gets coefficients for all the terms in an MCMC object.

Usage

# S3 method for mcmc
coef(
  object,
  conf_level = 0.95,
  estimate = median,
  simplify = TRUE,
  directional_information = FALSE,
  ...
)

Value

An data frame of the coefficients with the columns indicating the term, estimate, lower and upper credible intervals and svalue

Arguments

object

The MCMC object to get the coefficients for

conf_level

A number specifying the confidence level. By default 0.95.

estimate

The function to use to calculate the estimate.

simplify

[Deprecated] Must be TRUE.

directional_information

A flag specifying whether the svalue column should be calculated using extras::directional_information() instead of extras::svalue(). The default value will change from FALSE to TRUE in a future release; set the argument explicitly to avoid the deprecation warning.

...

Unused.

Methods (by class)

  • coef(mcmc): Get coefficients for terms in mcmc object

See Also

Examples

Run this code
coef(mcmcr_example, directional_information = FALSE)
coef(mcmcr_example, directional_information = TRUE)

Run the code above in your browser using DataLab