An data frame of the coefficients with the columns indicating the
term, estimate,
lower and upper credible intervals and svalue
Arguments
object
The MCMC object to get the coefficients for
conf_level
A number specifying the confidence level. By default 0.95.
estimate
The function to use to calculate the estimate.
simplify
Must be TRUE.
directional_information
A flag specifying whether the svalue column
should be calculated using extras::directional_information() instead of
extras::svalue().
The default value will change from FALSE to TRUE in a future release;
set the argument explicitly to avoid the deprecation warning.
...
Unused.
Methods (by class)
coef(mcmc): Get coefficients for terms in mcmc object